@@ -1,4 +1,4 @@
-# Copyright (c) 2025 OpenStack Foundation
+# Copyright (c) 2025 Thomas Goirand <zigo@debian.org>
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,6 +17,7 @@ import uuid
 from datetime import datetime
 import ssl
 import re
+from functools import wraps
 
 from flask import Flask, request, jsonify
 from requests.adapters import HTTPAdapter
@@ -92,7 +93,7 @@ def get_vm_details_from_source_cloud(vm_identifier):
             base_session.session.mount('https://', legacy_adapter)
         adapter      = ks_loading.load_adapter_from_conf_options(CONF, "source_cloud", session=base_session, auth=auth)
     except:
-        LOG.error(f"Cloud not load configuration for source_cloud.")
+        LOG.error(f"Could not load configuration for source_cloud.")
         return None, None
 
     try:
@@ -102,7 +103,7 @@ def get_vm_details_from_source_cloud(vm_identifier):
             interface=adapter.interface,
         )
     except:
-        LOG.error(f"Cloud not connect to source_cloud.")
+        LOG.error(f"Could not connect to source_cloud.")
         return None, None
             
     # Try to find VM by UUID first
@@ -127,7 +128,7 @@ def get_vm_details_from_source_cloud(vm_identifier):
 app = Flask(__name__)
 
 # wrapper decorator, so we can pass the CONF
-# object ot the vmms/policy/enforcer.py
+# object to the vmms/policy/enforcer.py
 def require_vmms_policy(action):
     def decorator(f):
         @wraps(f)
@@ -285,7 +286,6 @@ def show_vm(migration_id):
 def update_vm(migration_id):
     """Update a VM migration - authentication required"""
     LOG.debug(f"🐛 API: update_vm called by user with migration_id: {migration_id}")
-    LOG.debug(f"🐛 DEBUG: This should NEVER be reached if policy enforcement works!")
 
     # Validate migration_id format
     if not is_valid_uuid(migration_id):
